#
# spec file for package easyeffects
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           easyeffects
Version:        7.2.3
Release:        1.2
Summary:        Audio effects for Pulseaudio applications
License:        GPL-3.0-or-later
URL:            https://github.com/wwmm/easyeffects
#Source0:        https://github.com/wwmm/easyeffects/archive/v%%{version}.tar.gz#/%%{name}-%%{version}.tar.gz
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  appstream-glib
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  itstool
BuildRequires:  ladspa-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  tbb-devel
BuildRequires:  update-desktop-files
BuildRequires:  zita-convolver-devel
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libbs2b)
BuildRequires:  pkgconfig(libebur128)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(lilv-0)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(rnnoise)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sigc++-3.0)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(soundtouch)
Requires:       dconf
Recommends:     lv2-calf >= 0.90.1
Recommends:     lv2-lsp-plugins
Recommends:     lv2-zam-plugins

%description
Easyeffects is a limiter, compressor, reverberation, stereo equalizer and auto volume
effects for pipewire applications.

%package doc
Summary:        Documentation of Audio effects for pipewire applications
BuildArch:      noarch

%description doc
This package contains documentation of Audio effects for pipewire applications

%lang_package

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup
# we don't need this
sed -i '/^meson.add_install_script/d' meson.build

export QMAKE_CFLAGS_ISYSTEM=-I

%build
export CC=gcc
export CXX=g++
export LDFLAGS="${LDFLAGS} -fPIC -Wl,--gc-sections -Wl,-O1"
%meson \
            -Db_ndebug=true \
            -Dc_args="${CFLAGS}" \
            -Dcpp_args="${CXXFLAGS}" \
            || (cat */meson-logs/meson-log.txt; exit 1)
######## IDIOTIC WORKAROUND ####################
sed -i s/isystem/I/g $(gcc -dumpmachine)/*.json
sed -i s/isystem/I/g $(gcc -dumpmachine)/*.ninja
######## END OF IDIOTIC WORKAROUND #############

%meson_build

%install
%meson_install

%suse_update_desktop_file -r com.github.wwmm.easyeffects "GTK;AudioVideo;Audio;Mixer;"

%find_lang easyeffects

%files lang -f easyeffects.lang
%exclude %{_datadir}/help/*/%{name}
%{_datadir}/locale/*/LC_MESSAGES/easyeffects-news.mo

%files
%{_bindir}/%{name}
%{_datadir}/applications/com.github.wwmm.%{name}.desktop
%{_datadir}/dbus-1/services/com.github.wwmm.%{name}.service
%{_datadir}/icons/hicolor/scalable/apps/com.github.wwmm.easyeffects.svg
%{_datadir}/icons/hicolor/symbolic/apps/com.github.wwmm.easyeffects-symbolic.svg
%{_datadir}/glib-2.0/schemas/com.github.wwmm.%{name}.*.xml
%{_datadir}/metainfo/com.github.wwmm.%{name}.metainfo.xml

%files doc
%license LICENSE
%doc CHANGELOG.md README.md
%{_datadir}/help/*/%{name}
%exclude %{_datadir}/locale/*

%changelog
* Sat Jan 11 2025 Gerald Chen <gerald_chen@foxmail.com>
- update to release 7.2.3
  + Improved compatibility with future PipeWire releases. This version will avoid compilation errors like #3620
- update to release 7.2.2
  + Updated translations
  + Added a workaround for a glibc(or maybe libstdc++) bug that affects locale management. What in turns breaks our spinbuttons on some locales.
* Tue Dec  3 2024 Gerald Chen <gerald_chen@foxmail.com>
- update to release 7.2.1
  + Fixed a bug that makes the application crash when the option Linux Studio Plugins package is not installed.
- update to release 7.2.0
  + Updated translations
  + Fixed a bug in the crystalizer plugin where the scale values were not being properly applied.
- update to release 7.1.9
  + Latency compensation can be applied to the spectrum plugin.It will delay its drawing so it matches the latency offset applied by the user on programs like Pavucontrol.
  + The command line option that shows EasyEffects version should work properly now.
  + Fixed a regression in the autoload preset code.
- update to release 7.1.8
  + The loudness plugin exposes the ISO 226:2023 standard that is now available in the LSP plugin.
  + Updated translations
  + Performance optmizations to the spectrum plugin and the LADSPA wrapper
  + We were not locking PipeWire's thread main loop before setting a  stream volume and mute controls. THis could cause these operations to fail in some situations
- update to release 7.1.7
  + Community Presets have been implemented. Users can install packages containing multiple Easy Effects presets to be imported and applied inside the application. These packages will be maintained and shipped by volunteers. You can search them on the repositories of your favorite distribution.
  + Added the ability of collapsing the sidebar to hide the effects list and expand the area of the effects user interface.
  + EasyEffects won't touch streams that define `PW_KEY_TARGET_OBJECT` to an output device that is different from the one EasyEffects is using.
  + Equalizer APO import feature can now apply Band-Pass filters.
  + A change in GTK 4.14.1 prevented to apply the values inserted into the text field of our SpinButton widgets. This issue is now resolved.
  + The latest Maximizer plugin releases do not have the ceiling control anymore. So we removed it from our user interface (you can use the plugin input gain to retrieve the same functionality).
  + Equalizer APO import feature does not crash anymore on Flatpak when invalid values are provided.
  + In order for Community Presets to be correctly shipped, packagers are invited to read and follow the guidelines linked inside the README of EasyEffects master branch.
  + Presets with Convolver and/or Noise Reduction (RNNoise) effects created before `7.2.0` version are deprecated. Please reload the irs/model file inside the Convolver/RNNoise UI and resave the preset.
* Sun Apr 21 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to release 7.1.6
  + Improved the pipeline management system. Non-limiter effects are placed before the limiter
    even if the last two plugins in the pipeline are a limiter followed by a level meter.
  + Fixed a regression that prevented the level meters to be updated under certain conditions.
  + Updated translations
- update to release 7.1.5
  + We now set monitor.passthrough = true in our virtual devices. This will allow latency offset
    to be properly applied by video players when PipeWire > 1.0.3 is released.
- update to release 7.1.4
  + EasyEffects will try to avoid moving to its virtual sources streams for which the user has
    set a custom target.object that is different from the mic EE is recording from. The stream
    has to be started when EE is already running for this logic to take effect.
  + The equalizer can export basic APO preset files
  + Our players/recorders tab will show the audio client binary name in the cases were no app name is defined.
  + EasyEffects version can be shown in the command line through the option --version
  + A workaround for a bug in gtk4 GtkLevelBar was implemented and will be kept in place until gtk developers fiz things on their side
* Fri Nov 10 2023 Boris Manojlovic <boris@steki.net>
- updated to latest release 7.1.3
- BuildRequires ladspa-devel added by Andreas Schneider <asn@cryptomilk.org>
- Features:
  + Updated translations
  + The spectrum has a new option that allows the dynamic vertical scale to be disabled.
  + Improved compatibility with the latest LSP releases.
  + Added a new control to the noise reduction plugin that allows the voice detection to be disabled.
  + The Filter effect has been improved with new parameters since it has been ported from Calf Studio to Linux Studio Plugins.
  + Noise reduction by RNNoise has been improved with the addition of Release and VAD Threshold controls.
  + Noise reduction by RNNoise can now mix the original and denoised signals to avoid the output to sound too "dry".
  + The Expander from Linux Studio Plugins can be used in Easy Effects.
  + The Equalizer bands now have an additional gain control that allows for more efficient input of values
    that are hard to set in the scale. More details at #1383.
  + Added the ability to select and load multiple files in the opening dialogs for presets,
    Convolver impulse responses and RNNoise models.
- Bug fixes:
  + Fixed a regression introduced in 7.1.2
  + The DeepFilterNet plugin can now be added to the preset file
  + Fixed an incorrect drawing of the impulse response file characteristics
  + Fixed a small bug the prevented the noise reduction voice activity threshold from being properly initialized.
  + Fixed the Solo button in the Equalizer band settings.
- Other notes:
  + This release is intended to work with versions of Linux Studio Plugins equal or greater than "1.2.10".
  + EasyEffects is now buildable also with libc++.
  + Easy Effects folders under /etc have been deprecated and presets located there won't be loaded anymore.
    At the moment only local presets under ~/.config/easyeffects are automatically loaded in the Presets Menu.
    In the future we will implement a new system to install, manage and import Community Presets.
* Sun Aug  6 2023 Matthias Eliasson <elimat@opensuse.org>
- update to release 7.0.6
- Features:
  + An "Experimental Features" section was added to our preferences window.
  + The native window of the LSP plugins can be used. This is an experimental feature intended only for advanced users. So expect some bugs.
  + Fractional semitone values can now be used in the Pitch Shift effect.
- Bug fixes:
  + The input/output device dropdown in our PipeWire tab is updated when the system default device changes and Use Default is enabled. This fixes #1989
* Sun Aug  6 2023 Matthias Eliasson <elimat@opensuse.org>
- update to release 7.0.5
- Features:
  + A new Level Meter plugin based on libebur128 has been added.
  + The Pitch plugin now uses the library SoundTouch instead of Rubberband. Hopefully some of the mysterious crashes that were happening with Rubbernand are not going to happen anymore.
  + Improved compatibility with recent PipeWire versions. More information at https://gitlab.freedesktop.org/pipewire/pipewire/-/issues/3196
- Bug fixes:
  + Active Equalizer filters are not set to Bell type anymore when the number of bands changes.
- Other notes:
  + Rabberband is not a dependency anymore since it has been replaced by SoundTouch.
* Sun Aug  6 2023 Matthias Eliasson <elimat@opensuse.org>
- update to release 7.0.4
- Features:
  + The presets menu now asks for confirmation before saving/deleting a preset file.
- Bug fixes:
  + The plugin reset should not make its controls innefective anymore.
- Other notes:
  + Speex is no longer incorrectly listed as a build dependency (speexdsp is still a build dependency)
  + RNNoise is no longer an autodependency. It is now required by default, if not available it must be explicitly disabled with -Denable-rnnoise=false
* Fri Apr 21 2023 Boris Manojlovic <boris@steki.net>
- update to latest release 7.0.3
- Features:
  + Updated translations.
  + The Equalizer "sort bands" feature is now ordering bands on GSettings,
    so the result can be saved into presets.
  + Improved performance when resetting keys.
  + The spectrum plugin update rate was improved. Different sampling rates
    should lead to similar update frequencies visually.
  + The update interval used by level meters and the spectrum can be customized by the user.
  + The equalizer band gain slider value can be updated in larger steps.
    Fine grain control is still possible through the keyboard up/down keys.
  + Small improvements to the echo canceller.
- Bug fixes:
  + A small mistake was done in the last release. Making a new one
    to make sure people have the right branch in the package
  + Fixed the "Large Empty Hall" preset selection in the Reverberation effect.
  + Fixed some misuses of PipeWire's API that can potentially fix
    some random bugs some users are facing.
  + The echo canceller probes were not being linked to the soundcard after
    the move to multiple filters intances. This should be fixed now.
- Other notes:
  + As we are removing code deprecated by GTK 4.10 the minimum GTK version has been increased.
* Thu Apr 20 2023 Martin Liška <mliska@suse.cz>
- Drop usage of binutils-gold as the package in unmaintained
  and will be dropped soon (boo#1210687).
* Fri Feb  3 2023 Boris Manojlovic <boris@steki.net>
- update to release 7.0.0
- Features:
  + It is now possible to add more than one filter instance to the effects pipeline.
  + A new Speech Processor plugin based on the Speex library was added. Besides providing noise suppression it also can detect voice activity.
    It is a decent alternative to the cases whre the rnnoise library does not work well.
  + Improved compatibility with Linux Studio Plugins 1.2.3.
  + GraphicEQ presets can be imported into the Equalizer effect.
  + The application name has been changed to Easy Effects to adhere to the naming conventions of GNOME Human Interface Guidelines.
  + The documentation has been updated.
  + Improved presets autoloading.
  + The Autogain silence threshold can now be configured by the user.
  + Dry and wet controls added to the Stereo Tools effect.
  + The echo canceller now has a residual noise suppression control also based on the Speex library.
- Bug fixes:
  + When the mouse was hovering over a chart the wrong value for the x axis coordinate was being shown. This regression is fixed.
- Other notes:
  + Because of the new multiple instances feature, the preset format has changed, but the old one is still compatible to be loaded.
    Anyway take in consideration that saving the current preset will always write it in the new format.
* Tue Oct 11 2022 Boris Manojlovic <boris@steki.net>
- updated to latest 6.3.0
- Features:
  + Multiband Gate implementation has been migrated from CALF to Linux Studio Plugins.
  + The preset autoloading code compatibility with bluez5 devices has been improved.
  + Wet/dry controls were added for some plugins
  + Effect interface is no longer loaded when the related lv2 plugin is not installed on the system.
    In its place a status message to the user is shown.
  + The documentation has been updated
  + Improved debug messages
  + Updated translations
  + Improved translations
  + The bypass state can be saved to the preset file. The reasons why this was done can be seen at #1039
  + The preset autoloading code compatibility with usb devices has been improved.
  + A dialog is shown to the user when a preset fails to load or a preset/impulse file fails to be imported.
  + The SideChain Gate plugin from Linux Studio Plugins is now used instead of the one from Calf Studio.
- Bug fixes:
  + Fixed a bug where EasyEffects could crash when closing its window while effects were being applied.
  + EasyEffects should not crash anymore when the user locale is not properly configured.
  + A workaround was implemented in our icon to deal with the lack of proper SVG support in QT.
* Fri Jun 24 2022 Boris Manojlovic <boris@steki.net>
- Update to latest release 6.2.6
- Features:
  + When effects are disable to an application we now set its target metadata to null.
    This will allow the media session manager (wireplumber) to properly move the stream to a new device.
  + A new configuration option was added. It allows EasyEffects to ignore streams whose purpose is to monitor sink devices.
    This will help to fix some of problems our users were having when using OBS.
  + The code that shows the stream sample format has been improved
  + The rnnoise library is now optional. This should help package maintainers to build a Debian package.
    See the issue #1000 for more information.
  + Our logs now show the source code line where the messages are being printed
- Bugfixes:
  + The "enable effects" checkbox in our window was not being updated when third party programs like pavucontrol
    moved the stream away from our virtual devices. This should be fixed now.
  + Fixed a crash that could happen when the maximum autogain history was changed.
  + Avoid crashes when pw-mididump is running
* Thu May 12 2022 Boris Manojlovic <boris@steki.net>
- Update to latest release 6.2.5
- Features:
  + The interface of the pitch plugin was improved
  + Our application icon is now compatible with desktops that uses QT
  + Our blocklist code will use the `application.id` tag if the stream sets it
  + In order to avoid problems with the mouse scroll the entries in the applications list shown in our `Players/Recorders`
    tab do not show a volume scale anymore. More details about the problem and the solution for it can be found on #1211
    and #1427
  + When no application is available for display in the `Players/Recorders` a message will be shown to the user
  + Many translation updates
- Bugfixes:
  + Fixed a bug where EasyEffeects crashed when the number of points displayed in the spectrum was changed while
    our pipeline was active and the spectrum widget was visible
  + The pipeline latency value displayed in our window could be wrong in some situations. This was fixed.
* Thu Apr 21 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to latest release 6.2.4
- Features:
  + There is a new setting allowing the user to select an
    inactivity timeout for the pipeline. When no client is playing
    to or recording from our devices the filters will be unlinked
    after the timeout is reached. This is done to make sure we do
    not waste CPU power processing silence.
  + The autogain plugin now allows the user to select which of the
    three loudness are used to calculate the geometric mean.
  + The autogain plugin now allows the maximum history to be set
    and does not use libebur128 histogram mode anymore. This should
    avoid the cases where the Integrated loudness gets stuck
    forever in the same value.
  + EasyEffects icon has been updated in a way that should make it
    visible in QT desktops.
- Bugfixes:
  + The command line option that returns the global bypass state is
    working again.
* Wed Feb  2 2022 Boris Manojlovic <boris@steki.net>
- Updated to latest release 6.2.3
- Features:
  + The crossfeed filter should deal better with PipeWire's dynamic latency switches.
    Jumps in volume level should not happen anymore in these situations.
  + Support for the next PipeWire release `0.3.44`
  + The autogain filter should deal better with PipeWire's dynamic latency switches.
    Jumps in volume level should not happen anymore in these situations.
  + We added an option that allows the volume and mute state of our virtual devices to be reset when EasyEffects starts.
    It should help with the cases were our devices are muted by the audio server for unknown reasons.
  + Better support for computer suspending.
  + Updated translations
- Bugfixes:
  + Fixed a bug that prevented mono microphones from properly working with EasyEffects
  +  Fixed a bug where trying to create an autoloading profile without having presets caused the application to crash.
* Tue Jan 11 2022 Boris Manojlovic <boris@steki.net>
- Updated to latest release 6.2.1
- Bugfixes
  + Fixed a bug where setting a equalizer band quality to zero would lead to an application crash.
  + More robust parsing to import APO presets saved with comma as thousands separator in central frequency band.
- Features
  + LibAdwaita is used to create some parts of our window and for handling
    the switching between dark and light themes.
  + The settings menu has been redesigned using LibAdwaita widgets.
  + Equalizer APO preset import feature has been improved to apply not only the Bell filter,
    but also other supported ones (at the moment only the Bandpass filter is not available in LSP plugin).
  + The Reset All Settings function in our menu should work in Flatpak now.
  + We have a new option that allows the user to disable our menus autohide.
    This may help to workaround some bugs Popover menus currently have on gtk4.
- Notes
  + The fmt library is a new dependency https://github.com/fmtlib/fmt. At least while the c++
    compilers do not implement its features. This is expected to happen in the next years.
  + GTKMM and GLIBMM are not a dependency anymore. We now use gtk4 directly.
* Sat Dec  4 2021 Boris Manojlovic <boris@steki.net>
- Updated to latest release 6.1.5
- Added
  + It is now possible to combine impulse responses in the Convolver interface.
    A new impulse file is generated and it should be visible in the impulse list.
  + Improved x axis drawings in our plots. Now the number of labels is adjusted
    dynamically depending on our window width.
  + The documentation has been updated reflecting the new EasyEffects features.
    Old references about PulseEffects have been removed. The documentation button has been added in the menu section.
  + The Limiter and the Multiband Compressor plugins can now use an optional external sidechain.
  + The Autogain plugin now allows the user to select which Loudness is used as reference for the volume correction.
  + The APO Profile Import feature of Equalizer plugin now parses the "Pre Amplification" parameter.
  + Optional Cubic Volume can be enabled in General Settings.
- Fixed
  + When a spinbutton is filled with an out of range value, now it is updated with the
    lowest/highest value rather than resetting to the previous one.
  + The application window now remembers the maximized state and restores it on the next opening event.
  + The Spectrum plugin was supposed to enter passthrough whenever it was not visible,
    but this was happening only when our window was closed.
  + Improved support for Assistive Technology.
  + The probes used in some filters like the Compressor and the Limiter were not being relinked
    after changing the order of the plugins in the pipeline. It should be working now.
- dependency
  + The tbb library is a new dependency https://www.threadingbuildingblocks.org
* Sun Oct  3 2021 Boris Manojlovic <boris@steki.net>
- updated to latest release 6.1.3
  * Prevented a case in which Spectrum were crashing.
  * Hopefully crashes like the one reported
    at https://github.com/wwmm/easyeffects/issues/1172 are fixed
- cleanup of multiple old requirements (gstreamer ladspa ...)
* Mon Sep 20 2021 Boris Manojlovic <boris@steki.net>
- removed PR-1159-App-info-UI-management-improved.patch as changes
  were applied
- updated to release 6.1.2
  + Improved compatibility with WirePlumber.
    This is needed to run on systems that decided to use it instead
    of the built-in PipeWire session manager.
    More information at https://github.com/wwmm/easyeffects/issues/1144
* Mon Sep 20 2021 Boris Manojlovic <boris@steki.net>
- add upstream patch PR-1159-App-info-UI-management-improved.patch
* Mon Sep 20 2021 Boris Manojlovic <boris@steki.net>
- updated to latest release 6.1.1
- Added:
  * When trying to add an autoloading profile for a device already
    in the list its target preset will be updated. This way we can change
    the profile preset without having to remove and recreating it.
  * The preset autoloading support implementation was redesigned again.
    It should work on more hardware now. For more information see issue 1051.
  * If the Limiter or the Maximizer are set in the last position of the plugin stack,
    new plugins are added at the second to last position in order
    to prevent hardware damage on eventually high output level.
  * Removing an application from the blocklist, its previous enabled state is restored.
- Fixed:
  * Sometimes when removing imported models from the noise reduction
    plugin the current used model was not properly updated. This should be fixed now.
  * When editing presets files in an external editor,
    duplicated entries won't be shown in our presets menu.
  * Now the blocklist is correctly set when switching presets.
  * Now the status of the global bypass button is correctly updated when changing plugin stack.
  * Missing icons on the system should not be shown inside the application info UI
  (if an application icon could not be shown even if you're sure it's correctly installed, please open an issue).
  * Some icons not showing in Plasma DE with Breeze icon theme should appear now.
* Mon Aug 23 2021 Boris Manojlovic <boris@steki.net>
- switch the recommends from ladspa-zam-plugins to lv2-zam-plugins (boo#1189542)
* Tue Aug 17 2021 Boris Manojlovic <boris@steki.net>
- updated to latest release 6.1.0
- Added
  + Updated Chinese translation.
  + Updated Italian translation.
  + Added support for the compressor parameter Boost Amount
  + The multiband compressor plugin now uses the stereo multiband
    compressor plugin from Linux Studio Plugins instead of the one from Calf Studio.
  + The limiter plugin now uses the stereo limiter plugin from
    Linux Studio Plugins instead of the one from Calf Studio.
  + LV2 filters now are spawned in PipeWire graph only when loaded the first time.
    Once loaded, they remain connected until EasyEffects shutdown.
- Fixed
  + The echo canceller sampling rate is now properly set.
  + The threshold parameter from the deesser plugin is now saved to the preset file.
  + Improved band splitting for crystalizer with new default intensity values.
  + Depending on the input gain or output gain values the corresponding
    level bars could not be aligned.
  + When adding more equalizer bands they are set to Bell instead of Off.
  + Equalizer APO presets loading is now working properly on locales different than C.
  + Improved linking management between port filter nodes in PipeWire.
  + The crystalizer plugin signal amplification was too high before.
    It should be within more reasonable levels now.
* Mon Jul 26 2021 Andreas Schwab <schwab@suse.de>
- Make use of gold optional and disable it on riscv64
* Wed Jul 21 2021 Boris Manojlovic <boris@steki.net>
- removed Recommends handling for -lang package
- moved documentation into -docs package
- spec cleanup
* Sat Jul 17 2021 Boris Manojlovic <boris@steki.net>
- updated to latest release 6.0.3
  + Transient windows are now propoerly set for some plugins dialogs
  + the convolver menu is back to the old style
  + the convolver menu is back to the old style
  + Italian translation updated
  + Merge pull request #1019 from Digitalone1/master
  + only autoload a preset if the device is the current input/output device
  + Merge branch 'master' of https://github.com/wwmm/easyeffects
  + improved resampler
  + Fixed a bug that could make the pitch plugin to not be properly initi…
  + Updated Dutch translation
  + Merge pull request #1026 from Vistaus/master
  + autogain plugin: do not calculate the range twice
  + using the css opacity property to show/hide the saturation warning icon
  + fixing the ratio locale in the compressor and get interface
  + fixing the ratio locale in the deesser interface
  + fixing the ratio locale in the reverb interface
  + fixing the ratio locale in the limiter and gate interface
  + fixing the deesser and gate interface
  + fixing the compressor interface
  + fixing the gtkscale locale
* Tue Jul 13 2021 Boris Manojlovic <boris@steki.net>
- update to latest release 6.0.2
  + removal of boost dependencies
  + removal of gstreamer dependencies
  + added gtk4 dependencies
  + for now gcc10 only build
  + pipewire requirements added
* Sat May 15 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to version 4.8.5
  Added:
  * Improved compatibility with dconf 0.40. Now our plugins should
    be enabled when using this version.
* Wed Mar  3 2021 Antonio Larrosa <alarrosa@suse.com>
- Revert the last change. pulseeffects requires the real pulseaudio
  so keep the Requires: pulseaudio (boo#1182730).
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Require the pulseaudio-daemon capability instead of the
  pulseaudio package, so alternative implementations can be used
  (boo#1182730).
* Fri Jan  8 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to version 4.8.4
  Added:
  * Added Allpass filter in Equalizer plugin.
  Fixed:
  * The equalizer UI is now correctly shown when a profile with
    30 bands is loaded at startup.
  * Added a workaround for systems that were crashing because the
    locale is not correctly set at system level.
  Note to packagers:
  * This is the last release supporting Pulseaudio. The following
    PulseEffects releases will be based on the new Pipewire
    multimedia server and only fixes to critical bugs will be
    backported to the legacy pulseaudio branch
    https://github.com/wwmm/pulseeffects/tree/pulseaudio-legacy.
- Changes from 4.8.3
  Added:
  * New Noise Reduction plugin based on the RNNoise library.
  * Band Quality factor exposed in the Equalizer main interface.
  * A new settings was added to the general section of our settings
    menu: Activity Timeout. It is the time during which
    PulseEffects monitors if there is any application playing audio.
    If there is none we stop our playback stream in order to save
    cpu usage. This timeout has been in place for a long time but
    until now its value could not be configured by the user.
  * When no application is playing audio PulseEffects pipeline is
    now put in the ready state instead of the paused state. This
    should help to reduce cpu usage in situations like the ones
    described in https://github.com/wwmm/pulseeffects/issues/829
  * Updated Chinese translation.
  Fixed:
  * Values outside GTK widgets are now shown according to system
    locale settings.
  * Applying APO Equalizer preset when locale is different than "C"
    is now working properly.
  * Equalizer and Crystalizer UI redesigned: band wrapper is
    extended to fit all the available horizontal space; homogeneous
    property has been applied to get the same space between band sliders.
  * App info and plugin interfaces made scrollable: now PulseEffects
    window does not change its size when switching beetween plugins.
  * Loudness plugin: removed reference signal button (test signals can
    be used in its stead); input value is now saved to preset.
  Note to packagers:
  * The Noise Reduction is an optional plugin. For it to be
    available to the user the library RNNoise
    https://github.com/xiph/rnnoise has to be installed when
    PulseEffects is compiled.
* Mon Sep 21 2020 andy great <andythe_great@pm.me>
- Update to version 4.8.2.
  * Fix when importing Equalizer APO presets the bands were not
    being set to the APO mode.
- Changelog from 4.8.1.
  * Blocklist adopted and related command modified as a checkbutton
    inside the app info ui.
  * Pulseaudio’s media name property is shown for each application
    in the Applications section.
  * Deesser UI redesigned and applied homogeneous property to all
    plugin UI to get same space between controls and make them fit
    all the available horizontal space.
  * Modified Applications row in the left side plugin list to show
    an icon according to input/output effects while the pipeline
    global level meter is only shown when something is
    recording/playing
  * The feature that shows the last used preset in the preset menu
    button label was improved. When seeing input effects widget it
    shows the last used input preset. And when seeing output
    effects widgets it shows the last used output preset.
  * New application icon.
* Sat Aug 29 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.8.0
  Added:
  * Loudness plugin has been replaced with the new Loudness
    Compensator by Linux Studio Plugins.
  * The Stereo Tools and the Maximizer plugins can now be used
    when applying effects to microphone signals.
  * New parameters have been added to the following plugins:
    Compressor, Gate and Limiter.
  * Plugin user interfaces have been redesigned with
    checkbutton list and new global output level meter for both
    output and input pipelines.
  * The user has now the ability to change the minimum and
    maximum frequency in the spectrum user interface.
  * New command line that allows to hide the window when
    running PulseEffects in service mode. This will allow tray
    applets to hide our window.
  * Initial support to Equalizer APO presets.
  * Improved Slovak and Czech Translations.
  Removed:
  * The spectrum scaling feature was removed as it leads to
    wrong mouse hover values when used
    https://github.com/wwmm/pulseeffects/issues/733. And
    fixing this will require the addition of an amount of code
    complexity that does not seem worth it.
  Note to packagers:
  * This release is using GTKMM 3.24 features and Linux Studio
    Plugins >= `1.1.24`. If you can not use any of these
    libraries do not upgrade to PulseEffects 4.8.0!
  * MDA is not needed anymore as optional dependency.
  version 4.7.3:
  Added:
  * PulseEffects now searches for presets in /etc/PulseEffects
    and directories specified by \$XDG_CONFIG_DIRS environment
    variable.
  * Our interface now shows third party Plugins credits.
  * Each plugin now has a reset button
  * Improved convolver impulse response files plot
  * Applications entry now have a blacklist button to make it
    easier to blacklist an application the user does not want
    effects to be applied.
  Fixed:
  * Fixed a severe memory leak that happened whenever the
    window was closed.
  * PulseEffects no longer crashes when an empty or corrupted
    preset is provided.
  * Fixed laxity setting not being applied in the deesser
- Fixes boo#1171896
* Wed May 20 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.7.2
  Added:
  * Compatibility to Linux Studio Plugins `1.1.14`
  * The convolver plugin now accepts the wav extension in the
    impulse files.
  * Checking exceptions in the main function.
  * Headers deprecated in Boost 1.72 were replaced.
  Notes to package maintainers:
  * As the `bypass` property in Linux Studio Plugins `1.1.14`
    was renamed to `enabled` this new PulseEffects version
    won't work with older Linux Studio Plugins versions.
    Although I could add checks and somehow try to support both
    versions this makes the code ugly. And I think that nowadays
    upgrading LSP should not be hard. If it is do not upgrade to
    PE `4.7.2`.
- Fixes boo#1171896
* Tue Mar  3 2020 Luigi Baldoni <aloisio@gmx.com>
- Spec cleanup
- Dropped group tag
* Mon Mar  2 2020 andy great <andythe_great@pm.me>
-Update to version 4.7.1 (see CHANGELOG.md)
* Mon Jan 13 2020 andy great <andythe_great@pm.me>
-Fix recommended dependencies to enable all functionalities.
-Update to version 4.7.0 (see CHANGELOG.md)
  * Improved Italian translations.
  * Do not open the main window when listing the available presets
  through command line options.
  This will also help third party tools like
  https://github.com/boomshop/pulseffectstray
* Mon Sep 23 2019 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 4.6.8 (see CHANGELOG.md)
  * It is now possible to set different buffer and latency values
    for the pulsesrc
    and the pulsesink plugins.
    This means that there is more room to reduce the overall latency.
    Pulsesrc is at the start of the effects pipeline and
    pulsesink at its end.
* Sun Aug 18 2019 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 4.6.6 (see CHANGELOG.md)
* Thu Jun 20 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.6.4 (see CHANGELOG.md)
- Added Recommends for external plugin packages
* Tue Feb 12 2019 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v4.5.0)
